@@ -13,12 +13,13 @@ import textwrap
 
 import hpc_suite as hpc
 from hpc_suite.action import OrderAction
+from hpc_suite.generate_job import parse_hostname
 
-from . import gen
+from . import gen_input
 from . import extractor
 from . import opt_extractor
 from . import freq_extractor
-from . import submit
+from . import gen_job
 from . import cd_extractor
 
 
@@ -47,9 +48,9 @@ def check_file(file_name, extension):
     return
 
 
-def generate_input_func(user_args):
+def generate_input_func(user_args, hpc_args):
     """
-    Wrapper function for CLI gen call
+    Wrapper function for CLI gen_input call
 
     Parameters
     ----------
@@ -70,7 +71,9 @@ def generate_input_func(user_args):
 
     # Substitute atoms if requested
     if sub:
-        labels, labels_nn = gen.subsititute_element(sub, labels, labels_nn)
+        labels, labels_nn = gen_input.subsititute_element(
+            sub, labels, labels_nn
+        )
 
     # Freeze all hydrogens
     if user_args.opt_H_only:
@@ -135,7 +138,7 @@ def generate_input_func(user_args):
             else:
                 ecp_spec[atom] = user_ecp[atom]
 
-    gen.gen_input(
+    gen_input.gen_input(
         file_name, labels, coords, user_args.charge, user_args.mult,
         user_args.method, bs_spec, ecp_spec=ecp_spec,
         subiso=user_args.subiso, chelpg=user_args.chelpg,
@@ -143,9 +146,9 @@ def generate_input_func(user_args):
     )
 
 
-def submit_func(user_args):
+def gen_job_func(user_args, unknown_args):
     """
-    Wrapper function for CLI submit call
+    Wrapper function for CLI gen_job call
 
     Parameters
     ----------
@@ -158,25 +161,60 @@ def submit_func(user_args):
 
     """
 
-    # Convert com file to data file with correct memory and number of cores
-    submit.create_data_file(
-        user_args.com_file_name,
-        user_args.n_cores
-    )
+    hpc_args = hpc.read_args(['generate_job'] + unknown_args)
+
+    if hpc_args.profile == 'read_hostname':
+        machine = parse_hostname()
+    else:
+        machine = hpc_args.profile
+
+    supported_machines = [
+        "csf3",
+        "csf4"
+    ]
+
+    if machine not in supported_machines:
+        sys.exit("Error: Unsupported machine")
+
+    default_mod = {
+        "csf3": "apps/binapps/gaussian/g16c01_em64t",
+        "csf4": "gaussian/g16c01_em64t_detectcpu"
+    }
+
+    default_scratch = {
+        "csf3": "/scratch/$USER/Gaussian/gau_temp_$JOB_ID",
+        "csf4": "/scratch/$USER/Gaussian/gau_temp_$SLURM_JOBID"
+    }
+
+    default_chk = {
+        "csf3": "$CurrDir/$JNAME.chk",
+        "csf4": "$JNAME.chk"
+    }
+
+    default_version = {
+        "csf3": "$g16root/g16/g16",
+        "csf4": "$g16root/g16/g16"
+    }
+
+    # GB per core
+    mem_multiplier = {
+        "csf3": 4,
+        "csf4": 4
+    }
 
     # Create submission script
-    submit.create_submission_script(
+    gen_job.create_submission_script(
         "{}.DATA".format(user_args.com_file_name[:-4]),
         user_args.n_cores,
+        user_args.n_cores * mem_multiplier[machine],
+        machine,
+        default_mod[machine],
+        default_scratch[machine],
+        default_chk[machine],
+        default_version[machine],
         gen_fchk=not user_args.no_gen_fchk,
-        short=user_args.short
     )
 
-    if not user_args.no_qsub:
-        os.system("qsub {}.sh {:d}".format(
-            user_args.com_file_name[:-4], user_args.n_cores)
-        )
-
     return
 
 
@@ -496,50 +534,50 @@ def read_args(arg_list=None):
 
     # Generate Input files
 
-    gen_inp = subparsers.add_parser(
-        'gen',
+    gen_input = subparsers.add_parser(
+        'gen_input',
         formatter_class=RawTextHelpFormatter,
         description="\
         Generates Gaussian input (.com) file from .xyz file\n\
         Default calculation is opt+freq, with all atoms treated with cc-PDVZ"
     )
-    gen_inp.set_defaults(func=generate_input_func) # noqa
+    gen_input.set_defaults(func=generate_input_func) # noqa
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "xyz_file",
         type=str,
         metavar="xyz_file",
         help="xyz file containing atomic coordinates"
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "charge",
         type=int,
         metavar="charge",
         help="Charge of molecule/ion/complex"
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "mult",
         type=int,
         metavar="multiplicity",
         help="Spin Multiplicity (2S+1) of molecule/ion/complex"
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "method",
         type=str,
         metavar="method",
         help="Either 1) DFT Functional - PBE, PBE0, B3LYP \n" +
              "Or     2) Method -  MP2"
     )
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "--no_opt",
         action="store_true",
         help="Skip optimisation"
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "--hq",
         type=str,
         default=[],
@@ -548,7 +586,7 @@ def read_args(arg_list=None):
         help="Increase basis set quality for these labels to cc-PDTZ"
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "--ecp",
         type=str,
         default=[],
@@ -565,7 +603,7 @@ def read_args(arg_list=None):
         )
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "--sub",
         type=str,
         default=[],
@@ -574,21 +612,22 @@ def read_args(arg_list=None):
         help="Use atom Y in place of atom X (all instances)"
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "--chelpg",
-        action="store_true",
+        type=str,
+        default='',
         choices=["charge", "charge_dipole"],
         help="Express electronic potential as charges and dipoles with CHELPG"
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "--subiso",
         default=[],
         nargs="+",
         help="For labels XX, YY, ZZ use mass MMM"
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "--frozen",
         type=str,
         default='',
@@ -598,7 +637,7 @@ def read_args(arg_list=None):
         the same ordering as the coordinates"""
     )
 
-    gen_inp.add_argument(
+    gen_input.add_argument(
         "--opt_H_only",
         action="store_true",
         help="Freeze all atoms other than hydrogens"
@@ -606,48 +645,42 @@ def read_args(arg_list=None):
 
     # Submission script and submission
 
-    submission = subparsers.add_parser(
-        "submit",
+    gen_job = subparsers.add_parser(
+        "gen_job",
         formatter_class=RawTextHelpFormatter,
         description="""
-        Submit .com file to CSF SGE queue as job.
+        Generate submission script for .com file
         """
     )
 
-    submission.set_defaults(
-        func=submit_func
+    gen_job.set_defaults(
+        func=gen_job_func
     )
 
-    submission.add_argument(
+    gen_job.add_argument(
         "com_file_name",
         type=str,
         help="Gaussian .com file name"
     )
 
-    submission.add_argument(
+    gen_job.add_argument(
         "n_cores",
         type=int,
         help="Number of cores (threads) to request"
     )
 
-    submission.add_argument(
+    gen_job.add_argument(
         "--short",
         action="store_true",
         help="Request short queue (1 hour and 12 cores max)"
     )
 
-    submission.add_argument(
+    gen_job.add_argument(
         "--no_gen_fchk",
         action="store_true",
         help="Skip generation of formatted checkpoint file"
     )
 
-    submission.add_argument(
-        "--no_qsub",
-        action="store_true",
-        help="Do not submit to queue using qsub"
-    )
-
     # Vibrational mode extractor
 
     extract = subparsers.add_parser(
@@ -830,7 +863,7 @@ def read_args(arg_list=None):
     _args, _ = parser.parse_known_args(arg_list)
 
     # select parsing option based on sub-parser
-    if _args.prog in ['extractor']:
+    if _args.prog in ['extractor', 'gen_job', 'gen_input']:
         args, hpc_args = parser.parse_known_args(arg_list)
         args.func(args, hpc_args)
     else:
